%bcond_with doc
%bcond_without qt5

Name:		doxygen
Epoch:		1
Version:	1.9.7
Release:	%mkrel 1
Summary:	A documentation system for C/C++
Group:		Development/Other
License:	GPLv2+
URL:		https://www.doxygen.nl/
Source0:	https://doxygen.nl/files/%{name}-%{version}.src.tar.gz
## upstream patches

## fedora patches

BuildRequires:	bison
BuildRequires:	cmake
BuildRequires:	flex
BuildRequires:	gcc-c++
BuildRequires:	git-core
BuildRequires:	graphviz
BuildRequires:	pkgconfig(libpng)
%if %with qt5
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Xml)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Widgets)
%endif
%if %with doc
BuildRequires:	tetex-latex
BuildRequires:	texlive-collection-basic
BuildRequires:	ghostscript
BuildRequires:	python3
%endif

Requires:	graphviz

%description
Doxygen is a documentation system for C, C++ and IDL. It can generate
an on-line class browser (in HTML) and/or an off-line reference manual
(in LaTeX) from a set of documented source files. There is also
support for generating man pages and for converting the generated
output into Postscript, hyperlinked PDF or compressed HTML. The
documentation is extracted directly from the sources.

Doxygen can also be configured to extract the code-structure from
undocumented source files. This can be very useful to quickly find
your way in large source distributions.

%if %with qt5
%package	doxywizard
Summary:	A GUI for creating and editing configuration files
Group:		Development/Other
Requires:	%{name} = %{epoch}:%{version}

%description	doxywizard
Doxywizard is a GUI for creating and editing configuration files that
are used by doxygen.
%endif

%prep
%setup -q
%autopatch -p1

find -type d -exec %{__chmod} 0755 {} \;

# build with system libpng
%{__rm} -rf libpng

%build
%cmake \
%if %with doc
	-Dbuild_doc=ON \
%else
	-Dbuild_doc=OFF \
%endif
%if %with qt5
	-Dbuild_wizard=ON \
%else
	-Dbuild_wizard=OFF \
%endif
	-Dbuild_xmlparser=ON \
	-DPYTHON_EXECUTABLE=%{__python3} \
	-DMAN_INSTALL_DIR=%{_mandir}/man1 \
	-DDOC_INSTALL_DIR=%{_docdir}/doxygen \
	-DCMAKE_INSTALL_PREFIX:PATH=%{_prefix} \
	-DBUILD_SHARED_LIBS=OFF

%cmake_build

%if %with doc
%cmake_build docs
%endif

%install
%if %with doc
cp doc/*.1 %{_vpath_builddir}/man/
cp doc/*.pdf %{_vpath_builddir}/pdf/
%endif

%cmake_install

%if %with doc
mv %{buildroot}%{_docdir}/doxygen .
%endif

%files
%if %with doc
%doc doxygen
%endif
%doc README.md
%{_bindir}/doxygen
%if %with doc
%{_mandir}/man1/doxygen.1*
%{_mandir}/man1/doxyindexer.1*
%{_mandir}/man1/doxysearch.1*
%endif

%if %with qt5
%files doxywizard
%{_bindir}/doxywizard
%if %with doc
%{_mandir}/man1/doxywizard.1*
%endif
%endif


%changelog
* Sun May 21 2023 kekepower <kekepower> 1:1.9.7-1.mga9
+ Revision: 1957521
- Update to version 1.9.7

* Tue Dec 27 2022 kekepower <kekepower> 1:1.9.6-1.mga9
+ Revision: 1927169
- Update to version 1.9.6

* Sun Aug 28 2022 kekepower <kekepower> 1:1.9.5-1.mga9
+ Revision: 1881478
- Update to version 1.9.5

* Fri May 06 2022 kekepower <kekepower> 1:1.9.4-1.mga9
+ Revision: 1856486
- Add upstream patch to fix build failure
- Update to version 1.9.4

* Fri Mar 18 2022 umeabot <umeabot> 1:1.9.3-2.mga9
+ Revision: 1797889
- Mageia 9 Mass Rebuild

* Mon Jan 03 2022 luigiwalser <luigiwalser> 1:1.9.3-1.mga9
+ Revision: 1766664
- 1.9.3

* Thu Aug 19 2021 kekepower <kekepower> 1:1.9.2-1.mga9
+ Revision: 1741925
- Update to version 1.9.2

* Fri Jan 08 2021 daviddavid <daviddavid> 1:1.9.1-1.mga8
+ Revision: 1669793
- new version: 1.9.1

* Wed Dec 30 2020 kekepower <kekepower> 1:1.9.0-1.mga8
+ Revision: 1665586
- Update to version 1.9.0

* Wed Dec 16 2020 umeabot <umeabot> 1:1.8.20-2.mga8
+ Revision: 1658329
- Rebuild for new Qt5

* Tue Aug 25 2020 kekepower <kekepower> 1:1.8.20-1.mga8
+ Revision: 1618935
- Update to version 1.8.20

* Sun Aug 09 2020 kekepower <kekepower> 1:1.8.19-1.mga8
+ Revision: 1612150
- Update to version 1.8.19

* Tue Apr 14 2020 luigiwalser <luigiwalser> 1:1.8.18-1.mga8
+ Revision: 1567374
- 1.8.18

* Tue Feb 18 2020 umeabot <umeabot> 1:1.8.17-2.mga8
+ Revision: 1541968
- Mageia 8 Mass Rebuild

* Fri Jan 03 2020 luigiwalser <luigiwalser> 1:1.8.17-1.mga8
+ Revision: 1475788
- 1.8.17
+ wally <wally>
- build with new cmake macros

* Sun Nov 17 2019 daviddavid <daviddavid> 1:1.8.16-1.mga8
+ Revision: 1461537
- new version: 1.8.16
- switch to python3
- remove merged upstream patches
- backport upstream patch to fix issue #7248

* Sat Mar 30 2019 umeabot <umeabot> 1:1.8.15-4.mga7
+ Revision: 1381568
- Qt5 Rebuild

* Wed Mar 13 2019 daviddavid <daviddavid> 1:1.8.15-3.mga7
+ Revision: 1375280
- backport some upstream patches
  * fix doxygen 1.8.15 segfault
  * Properly handle empty TOC in XML output
  * add a test for XML output with an empty TOC
  * Inconsistent whitespace removal for operators in 1.8.15
  * fix multilib issue
- add requirement on dot

* Sun Jan 27 2019 daviddavid <daviddavid> 1:1.8.15-2.mga7
+ Revision: 1361210
- add upstream patch to fix CMake 3.13 incompatibility
  * https://github.com/doxygen/doxygen/issues/6725

* Mon Dec 31 2018 daviddavid <daviddavid> 1:1.8.15-1.mga7
+ Revision: 1347533
- new version: 1.8.15
- remove merged upstream patch
- update URL and Sourve URL

* Sun Sep 23 2018 umeabot <umeabot> 1:1.8.14-4.mga7
+ Revision: 1297494
- Mageia 7 Mass Rebuild

* Wed Jun 06 2018 daviddavid <daviddavid> 1:1.8.14-3.mga7
+ Revision: 1234904
- add patch to fix build with new Qt5 >= 5.11.0

* Tue Dec 26 2017 wally <wally> 1:1.8.14-2.mga7
+ Revision: 1185419
- drop Qt4 support

* Tue Dec 26 2017 shlomif <shlomif> 1:1.8.14-1.mga7
+ Revision: 1185414
- Add BRs
- New version 1.8.14 (thanks to kekePower)

* Tue Jan 10 2017 wally <wally> 1:1.8.13-2.mga6
+ Revision: 1080829
- add patch from upstream to fix opendbx FTBFS

* Thu Dec 29 2016 luigiwalser <luigiwalser> 1:1.8.13-1.mga6
+ Revision: 1078634
- 1.8.13

* Tue Sep 06 2016 luigiwalser <luigiwalser> 1:1.8.12-1.mga6
+ Revision: 1050214
- 1.8.12

* Wed Dec 30 2015 luigiwalser <luigiwalser> 1:1.8.11-1.mga6
+ Revision: 917014
- 1.8.11
- remove patches

* Sat Dec 26 2015 luigiwalser <luigiwalser> 1:1.8.10-1.mga6
+ Revision: 915365
- 1.8.10
- BR graphviz (from fedora)
- if doc, BR texlive-collection-basic (for epstopdf)
- sync patches with fedora
- build with cmake
- reindent spec file

* Wed Oct 15 2014 umeabot <umeabot> 1:1.8.8-4.mga5
+ Revision: 741733
- Second Mageia 5 Mass Rebuild

* Sat Oct 11 2014 danf <danf> 1:1.8.8-3.mga5
+ Revision: 738052
- Added java-enum-crash.patch to fix crash while parsing sources

* Tue Sep 16 2014 umeabot <umeabot> 1:1.8.8-2.mga5
+ Revision: 678824
- Mageia 5 Mass Rebuild

* Fri Aug 22 2014 luigiwalser <luigiwalser> 1:1.8.8-1.mga5
+ Revision: 666353
- 1.8.8

* Mon Apr 21 2014 luigiwalser <luigiwalser> 1:1.8.7-1.mga5
+ Revision: 617294
- 1.8.7
- rediff patch 2

* Fri Jan 17 2014 luigiwalser <luigiwalser> 1:1.8.6-1.mga5
+ Revision: 566771
- 1.8.6
- rediff patch 2

* Sat Oct 19 2013 umeabot <umeabot> 1:1.8.5-3.mga4
+ Revision: 533844
- Mageia 4 Mass Rebuild

* Sat Sep 07 2013 shlomif <shlomif> 1:1.8.5-2.mga4
+ Revision: 475678
- Fix MGA #11163 . No need for specifying the path to make.

* Sat Aug 24 2013 luigiwalser <luigiwalser> 1:1.8.5-1.mga4
+ Revision: 470931
- 1.8.5
- remove upstream patch

* Sun Jun 30 2013 luigiwalser <luigiwalser> 1:1.8.4-1.mga4
+ Revision: 448602
- 1.8.4
- add patch from upstream via fedora to fix endless loop

* Fri Jan 11 2013 umeabot <umeabot> 1:1.8.3-2.mga3
+ Revision: 349076
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 31 2012 fwang <fwang> 1:1.8.3-1.mga3
+ Revision: 336516
- new version 1.8.3

* Wed Sep 26 2012 fwang <fwang> 1:1.8.2-1.mga3
+ Revision: 297836
- new version 1.8.2

* Fri Jul 13 2012 fwang <fwang> 1:1.8.1.2-1.mga3
+ Revision: 270475
- new version 1.8.1.2

* Mon Jun 11 2012 fwang <fwang> 1:1.8.1.1-1.mga3
+ Revision: 259624
- new version 1.8.1.1

* Thu Jun 07 2012 shlomif <shlomif> 1:1.8.1-1.mga3
+ Revision: 256654
- convert tabs to spaces and correct typos
- New version

* Sun Feb 26 2012 fwang <fwang> 1:1.8.0-1.mga2
+ Revision: 215098
- update file list
- new version 1.8.0

* Mon Dec 19 2011 shlomif <shlomif> 1:1.7.6.1-1.mga2
+ Revision: 184419
- New version with bugfixes to hangs (bug 3644)

* Sun Dec 04 2011 fwang <fwang> 1:1.7.6-1.mga2
+ Revision: 175894
- new version 1.7.6
- new version 1.7.5.1
- new version 1.7.5
+ tv <tv>
- new release

* Fri Jan 14 2011 rtp <rtp> 1:1.7.3-1.mga1
+ Revision: 17898
- imported package doxygen

